@@ -15,9 +15,7 @@ namespace Tomboy
 		Gtk.ComboBoxEntry find_combo;
 		Gtk.Button clear_search_button;
 		Gtk.CheckButton case_sensitive;
-		Gtk.HPaned hpaned;
 		Gtk.Label note_count;
-		Gtk.Button close_button;
 		Gtk.ScrolledWindow matches_window;
 		Gtk.VBox content_vbox;
 		Gtk.TreeViewColumn matches_column;
@@ -231,11 +229,6 @@ namespace Tomboy
 			return menubar;
 		}
 		
-		void ShowMenuItem (Gtk.Widget widget)
-		{
-			widget.Show ();
-		}
-		
 		Gtk.TreeView MakeTagsTree ()
 		{
 			Gtk.TreeView t;
@@ -360,7 +353,8 @@ namespace Tomboy
 
 			int cnt = 0;
 			foreach (Note note in manager.Notes) {
-				string nice_date = PrettyPrintDate (note.ChangeDate);
+				string nice_date =
+					GuiUtils.GetPrettyPrintDate (note.ChangeDate, true);
 
 				Gtk.TreeIter iter =
 					store.AppendValues (note_icon,  /* icon */
@@ -819,30 +813,6 @@ namespace Tomboy
 			return (Note) model.GetValue (iter, 3 /* note */);
 		}
 
-		string PrettyPrintDate (DateTime date)
-		{
-			DateTime now = DateTime.Now;
-			string short_time = date.ToShortTimeString ();
-
-			if (date.Year == now.Year) {
-				if (date.DayOfYear == now.DayOfYear)
-					return String.Format (Catalog.GetString ("Today, {0}"), 
-							      short_time);
-				else if (date.DayOfYear == now.DayOfYear - 1)
-					return String.Format (Catalog.GetString ("Yesterday, {0}"),
-							      short_time);
-				else if (date.DayOfYear > now.DayOfYear - 6)
-					return String.Format (
-						Catalog.GetString ("{0} days ago, {1}"), 
-						now.DayOfYear - date.DayOfYear,
-						short_time);
-				else
-					return date.ToString (
-						Catalog.GetString ("MMMM d, h:mm tt"));
-			} else
-				return date.ToString (Catalog.GetString ("MMMM d yyyy, h:mm tt"));
-		}
-		
 		void OnOpenNote (object sender, EventArgs args)
 		{
 			Note note = GetSelectedNote ();
